@@ -3,11 +3,11 @@ from itertools import chain, product
 
 from AnyQt.QtWidgets import QStyle, QSizePolicy, QFileDialog
 
-import Orange
+from Orange.data import Table
 from Orange.widgets import gui, settings
-from Orange.widgets.widget import OWWidget, Msg
+from Orange.widgets.widget import OWWidget, Msg, Output
 import orangecontrib.network as network
-
+from orangecontrib.network.readwrite import PajekBug
 
 NONE = "(none)"
 
@@ -18,8 +18,9 @@ class OWNxFile(OWWidget):
     icon = "icons/NetworkFile.svg"
     priority = 6410
 
-    outputs = [("Network", network.Graph),
-               ("Items", Orange.data.Table)]
+    class Outputs:
+        network = Output("Network", network.Graph)
+        items = Output("Items", Table)
 
     resizing_enabled = False
 
@@ -34,6 +35,7 @@ class OWNxFile(OWWidget):
         file_not_found = Msg('File not found: "{}"')
         vertices_length_not_matching = Msg('Vertices data length does not match the number of vertices')
         error_reading_file = Msg('Error reading file "{}"')
+        pajek_bug = Msg("{}")
     
     want_main_area = False
 
@@ -124,8 +126,8 @@ class OWNxFile(OWWidget):
 
     def readingFailed(self, message=''):
         self.graph = None
-        self.send("Network", None)
-        self.send("Items", None)
+        self.Outputs.network.send(None)
+        self.Outputs.items.send(None)
         self.info.setText('No data loaded.\n' + message)
 
     def openNetFile(self, filename):
@@ -133,15 +135,19 @@ class OWNxFile(OWWidget):
         if path.splitext(filename)[1].lower() not in network.readwrite.SUPPORTED_READ_EXTENSIONS:
             return self.readingFailed('Network file type not supported')
 
+        G = None
         try:
             G = network.readwrite.read(filename, auto_table=self.auto_table)
         except OSError:
             self.Error.file_not_found(''.format(filename))
             return self.readingFailed('Network file not found')
+        except PajekBug as ex:
+            self.Error.pajek_bug(str(ex))
         else:
             self.Error.file_not_found.clear()
+            self.Error.pajek_bug.clear()
         if G is None:
-            self.Error.error_reading_file(''.format(filename))
+            self.Error.error_reading_file(filename)
             return self.readingFailed('Error reading file "{}"'.format(filename))
         self.Error.error_reading_file.clear()
 
@@ -174,8 +180,8 @@ class OWNxFile(OWWidget):
         else:
             self.data_index = len(self.recentDataFiles)
 
-        self.send("Network", G)
-        self.send("Items", G.items() if G else None)
+        self.Outputs.network.send(G)
+        self.Outputs.items.send(G.items() if G else None)
 
     def openDataFile(self, filename):
         self.Error.vertices_length_not_matching.clear()
@@ -189,15 +195,15 @@ class OWNxFile(OWWidget):
                                    "No vertices data file specified"))
         else:
             self.readDataFile(filename)
-        self.send("Network", self.graph)
-        self.send("Items", self.graph.items() if self.graph else None)
+        self.Outputs.network.send(self.graph)
+        self.Outputs.items.send(self.graph.items() if self.graph else None)
 
     def readDataFile(self, filename):
         if not self.graph:
             self.Warning.no_network_file()
             return
 
-        table = Orange.data.Table.from_file(filename)
+        table = Table.from_file(filename)
 
         if len(table) != self.graph.number_of_nodes():
             self.Error.vertices_length_not_matching()
@@ -211,7 +217,7 @@ class OWNxFile(OWWidget):
                                        items.domain.metas)
                       if v.name not in table.domain]
             if domain:
-                table = Orange.data.Table.concatenate([table, items[:, domain]])
+                table = Table.concatenate([table, items[:, domain]])
 
         self.graph.set_items(table)
         self.info.setText(self.info.text().rpartition('\n')[0] + '\n' +
@@ -237,7 +243,8 @@ class OWNxFile(OWWidget):
                        "GML files (*.gml)",
                        "All files (*)")))
 
-        if not filename: return
+        if not filename:
+            return
         try: self.recentFiles.remove(filename)
         except ValueError: pass
         self.recentFiles.insert(0, filename)
@@ -255,12 +262,13 @@ class OWNxFile(OWWidget):
                      path.dirname(self.recentFiles[0]) if self.recentFiles else
                      '.')
 
-        filename = QFileDialog.getOpenFileName(
+        filename, _ = QFileDialog.getOpenFileName(
             self, 'Open a Vertices Data File', startfile,
             'Data files (*.tab *.tsv *.csv);;'
             'All files(*)')
 
-        if not filename: return
+        if not filename:
+            return
         try: self.recentDataFiles.remove(filename)
         except ValueError: pass
         self.recentDataFiles.insert(0, filename)
